.. :changelog:

Changelog
=========


Versions 0.2
------------

Release 0.2.0
^^^^^^^^^^^^^

`release date: 30 January 2016`

* Adds support for plotting FusionCatcher output.


Versions 0.1
------------

Release 0.1.0
^^^^^^^^^^^^^

`release date: 20 April 2016`

* First release.
* Support for plotting STAR-fusion output on human.hg19 and human.hg38.
